=========
Castellan
=========

Generic Key Manager interface for OpenStack.

* License: Apache License, Version 2.0
* Documentation: http://docs.openstack.org/developer/castellan
* Source: http://git.openstack.org/cgit/openstack/castellan
* Bugs: http://bugs.launchpad.net/castellan
